
import 'dart:async';

import 'package:flutter/services.dart';

class FlutterWxWorkerPlugin {
  static const MethodChannel _channel =
      const MethodChannel('flutter_wx_worker_plugin');

  StreamController<WeChatWorkAuthResponse> _responseAuthController = new StreamController.broadcast();
  Stream<WeChatWorkAuthResponse> get responseFromAuth => _responseAuthController.stream;


  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }


  Future<dynamic> _handler(MethodCall methodCall) {
    if ("onAuthResponse" == methodCall.method) {
      _responseAuthController.add(WeChatWorkAuthResponse.fromMap(methodCall.arguments));
    }

    return Future.value(true);
  }

  Future register({required String schema,required String corpId,required String agentId}) async {
    return await _channel.invokeMethod('registerApp',{
      'schema':schema,
      'corpId':corpId,
      'agentId':agentId,
    });
  }

  Future isWeChatInstalled() async {
    return await _channel.invokeMethod("isWeChatInstalled");
  }

  Future sendAuth({required String schema,required String appId,required String agentId,required String state}) async {
    if (state == null || state.length == 0){
      state = DateTime.now().millisecondsSinceEpoch.toString();
    }

    return await _channel.invokeMethod('sendAuth',{
      'schema':schema,
      'appId':appId,
      'agentId':agentId,
      'state':state
    });
  }

  void dispose(){
    _responseAuthController.close();
  }

}



class WeChatWorkAuthResponse {
  final int errCode;
  final String code;
  final String state;

  WeChatWorkAuthResponse.fromMap(Map map)
      : errCode = map['errCode'],
        code = map['code'],
        state = map['state'];
}